function varargout=plot(self,u,varargin)
% FUNCTION plot 
%   Plot scalar data values on the siMesh object.
%
% USAGE
%   Th.plot(u) or plot(Th,u) where Th is a siMesh object and u is
%   a vector of length Th.nq which contains the scalar data values 
%   on each vertices of the siMesh object.
%
%   Th.plot(u,key,value,...) allows additional key/value pairs to be 
%     used when displaying u. The key strings could be
%
%     'd'      to specify the d-simplicial meshes. Default d=Th.d
%     'labels' to specify the labels of the elementary meshes. 
%              Default [] i.e all.
%     'plan'   (only in dimension 2), if true display is done in x0y plane,
%        otherwise the z-axe is the scalar data values. Default false.
%
%   or any of the plot options depending of Th.d and Th.dim. Same key/pairs as
%
%     - patch   function for d=3 and dim=3 (no face)
%     - patch   function for d=3 and dim=2
%     - patch   function for d=3 and dim=1
%     - patch   function for d=2 and dim=2 with 'plan'==true
%     - trisurf function for d=2 and dim=2 with 'plan'==false
%     - patch   function for d=2 and dim=1 
%     - plot    function for d=1 and dim=1 
%
% SAMPLES
%   Th=fc_simesh.HyperCube(3,10);
%   U=Th.eval(@(x,y,z) cos(2*x-y+z).*sin(x+y-3*z));
%   figure(1)
%   Th.plot(U)
%   figure(2)
%   Th.plot(U,'d',2,'labels',[1,2,5],'edgecolor','w')
%
%    <COPYRIGHT>
  p = inputParser; 
  p.KeepUnmatched=true; 
  p.PartialMatching=false;
  p.addParamValue('d',self.d,@isscalar); 
  p.addParamValue('labels',[]); % select labels to draw
  p.addParamValue('plan',false);
  p.parse(varargin{:});
  R=p.Results;
  varargin=fc_tools.utils.deleteCellOptions(varargin,p.Parameters);
  if fc_tools.comp.isOctave()
    NotImplemented={'FaceAlpha','EdgeAlpha'};
    nv=length(varargin);
    varargin=fc_tools.utils.deleteCellOptions(varargin,NotImplemented);
    if length(varargin)<nv
      fprintf('[fc-simesh] ''FaceAlpha'' or ''EdgeAlpha'' not yet implemented in plot\n');
    end
  end
  
  if isempty(R.labels), idxlab=self.find(R.d);else idxlab=self.find(R.d,R.labels);end
  if isempty(idxlab), return;end

  PrevHold=fc_tools.graphics.SetHoldOn(true);
  if ~PrevHold, clf;hold on;end
  i=1;
  for ilab=[idxlab]
      H{i}=self.sTh{ilab}.plot(u,varargin{:});
      i=i+1;
  end
  fc_tools.graphics.RestoreHold(PrevHold)
  if nargout==1,varargout{1}=H;end
end
